@@ -4,7 +4,7 @@ import base64
 import queue
 import re
 import threading
-from typing import TYPE_CHECKING, Any, Callable, Dict
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional
 
 import pychrome
 import requests
@@ -15,6 +15,7 @@ from ..common import wait_until_finished
 from .browser import ChromeBrowser
 from .dom import DOMNode
 from .exceptions import ChromeException
+from .patches import patch_all
 
 if TYPE_CHECKING:
     from .options import ChromeOptions
@@ -22,13 +23,16 @@ if TYPE_CHECKING:
     Request = Dict[str, Any]
     Response = Dict[str, Any]
 
+# Apply all custom patches
+patch_all()
+
 
 class ChromeRemote:
     """Wrapper for Chrome DevTools Protocol Interface.
 
     Args:
         chrome_options: ChromeOptions parameters.
-        response_patterns: Repsonse URL patterns to capture.
+        response_patterns: Response URL patterns to capture.
     """
     def __init__(self, chrome_options: ChromeOptions, response_patterns: list[str]) -> None:
         self._chrome_options: ChromeOptions = chrome_options
@@ -37,21 +41,17 @@ class ChromeRemote:
         self._chrome_tab: pychrome.Tab
         self._response_patterns: list[str] = response_patterns
         self._response_queues: dict[str, queue.Queue[Response]] = {x: queue.Queue() for x in response_patterns}
-        self._requests: dict[str, Request] = {}  # _requests[rquest_id] = <Request>
+        self._requests: dict[str, Request] = {}  # _requests[request_id] = <Request>
         self._requests_lock = threading.Lock()
 
     @wait_until_finished(timeout=60)
-    def _connect_interface(self, port: int) -> bool:
+    def _connect_interface(self) -> bool:
         """Establish connection to Chrome and open new tab.
 
-        Args:
-            port: Remote's Chrome port.
-
         Returns:
             `True` on success, `False` on failure.
         """
         try:
-            self._dev_url = f'http://127.0.0.1:{port}'
             self._chrome_interface = pychrome.Browser(url=self._dev_url)
             self._chrome_tab = self._create_tab()
             self._chrome_tab.start()
@@ -63,10 +63,10 @@ class ChromeRemote:
         """Open browser, create new tab, setup remote interface."""
         # Open browser
         self._chrome_browser = ChromeBrowser(self._chrome_options)
+        self._dev_url = f'http://127.0.0.1:{self._chrome_browser.remote_port}'
 
         # Connect browser with CDP
-        self._connect_interface(self._chrome_browser.remote_port)
-
+        self._connect_interface()
         self._setup_tab()
         self._init_tab_monitor()
 
@@ -198,22 +198,25 @@ class ChromeRemote:
 
         def monitor_tab() -> None:
             """V8 OOM could crash Chrome's tab and keep websocket functional
-            like nothing bad happend, so we better monitor tabs index page
+            like nothing bad happened, so we better monitor tabs index page
             and check if our tab is still alive."""
             while not self._chrome_tab._stopped.is_set():
-                ret = requests.get('%s/json' % self._chrome_interface.dev_url, json=True)
-                if not any(x['id'] == self._chrome_tab.id for x in ret.json()):
-                    nonlocal tab_detached
-                    tab_detached = True
-                    self._chrome_tab._stopped.set()
+                try:
+                    ret = requests.get('%s/json' % self._dev_url, json=True)
+                    if not any(x['id'] == self._chrome_tab.id for x in ret.json()):
+                        nonlocal tab_detached
+                        tab_detached = True
+                        self._chrome_tab._stopped.set()
 
-                self._chrome_tab._stopped.wait(0.5)
+                    self._chrome_tab._stopped.wait(0.5)
+                except ConnectionError:
+                    break
 
         self._ping_thread = threading.Thread(target=monitor_tab, daemon=True)
         self._ping_thread.start()
 
         def get_send_with_reraise() -> Callable[..., Any]:
-            """Reraise "Tab has been stopped" instead of `UserAbortException` in
+            """Re-raise "Tab has been stopped" instead of `UserAbortException` in
             case of tab detach detected."""
             original_send = self._chrome_tab._send
 
@@ -249,7 +252,7 @@ class ChromeRemote:
         """Wait for specified response with pre-defined pattern.
 
         Args:
-            response_pattern: Repsonse URL pattern.
+            response_pattern: Response URL pattern.
 
         Returns:
             Response or None in case of timeout.
@@ -302,7 +305,7 @@ class ChromeRemote:
         """Get Document DOM tree.
 
         Args:
-            full: Flag wheather to return full DOM or only root.
+            full: Flag wether to return full DOM or only root.
 
         Returns:
             Root DOM node.
@@ -347,13 +350,13 @@ class ChromeRemote:
                                                         returnByValue=True)
         return eval_result['result'].get('value', None)
 
-    def perform_click(self, dom_node: DOMNode) -> None:
+    def perform_click(self, dom_node: DOMNode, timeout: Optional[int] = None) -> None:
         """Perform mouse click on DOM node.
 
         Args:
             dom_node: DOMNode element.
         """
-        resolved_node = self._chrome_tab.DOM.resolveNode(backendNodeId=dom_node.backend_id)
+        resolved_node = self._chrome_tab.DOM.resolveNode(backendNodeId=dom_node.backend_id, _timeout=timeout)
         object_id = resolved_node['object']['objectId']
         self._chrome_tab.Runtime.callFunctionOn(objectId=object_id, functionDeclaration='''
             (function() { this.scrollIntoView({ block: "center",  behavior: "instant" }); this.click(); })
@@ -364,7 +367,7 @@ class ChromeRemote:
         self._chrome_tab.wait(timeout)
 
     def stop(self) -> None:
-        """Close browser, dissconnect interface."""
+        """Close browser, disconnect interface."""
         # Close tab and browser
         if self._chrome_tab:
             try:
