@@ -1,13 +1,13 @@
 from __future__ import annotations
 
 import json
-import os
 from typing import Any
 
 from ..common import GUI_ENABLED, running_linux
 from ..paths import data_path, image_data
 from .error_popup import gui_error_popup
-from .utils import ensure_gui_enabled, invoke_widget_hook, setup_text_widget
+from .utils import (ensure_gui_enabled, generate_event_handler,
+                    invoke_widget_hook, setup_text_widget)
 
 if GUI_ENABLED:
     import tkinter as tk
@@ -27,7 +27,7 @@ def filtered_rubrics(rubrics: dict[str, Any],
     Returns:
         Filtered rubric dictionary.
     """
-    # Delete nodes
+    # Filter nodes
     if is_russian:
         # Rubrics for Russia
         rubrics = {k: v for k, v in rubrics.items() if v.get('isRussian', True)}
@@ -71,15 +71,15 @@ def gui_rubric_selector(is_russian: bool = True) -> dict[str, Any] | None:
         or `None` if nothing selected.
     """
     # Locate and load rubrics list
-    rubric_path = os.path.join(data_path(), 'rubrics.json')
-    if not os.path.isfile(rubric_path):
+    rubric_path = data_path() / 'rubrics.json'
+    if not rubric_path.is_file():
         raise FileNotFoundError(f'Файл {rubric_path} не найден')
 
     try:
         with open(rubric_path, 'r', encoding='utf-8') as f:
             rubrics = filtered_rubrics(json.load(f), is_russian=is_russian)
     except json.JSONDecodeError as e:
-        gui_error_popup(f'Файл {os.path.basename(rubric_path)} повреждён:\n{e}')
+        gui_error_popup(f'Файл {rubric_path.name} повреждён:\n{e}')
         return None
 
     # Window layout
@@ -137,7 +137,7 @@ def gui_rubric_selector(is_russian: bool = True) -> dict[str, Any] | None:
         query = search_widget.get()
         window['-TREE-'].filter(query)  # noqa: F821
 
-    search_widget.bind('<<Change>>', lambda e: perform_rubric_search())
+    search_widget.bind('<<Change>>', generate_event_handler(perform_rubric_search))
 
     # Return rubric
     ret_rubric = None
