@@ -1,9 +1,11 @@
 from .file_writer import FileWriter
 from .csv_writer import CSVWriter
 from .json_writer import JSONWriter
+from .xlsx_writer import XLSXWriter
 
 __all__ = [
     'FileWriter',
     'CSVWriter',
+    'XLSXWriter',
     'JSONWriter',
 ]
